@@ -32,6 +32,7 @@
 #include <gconf/gconf-client.h>
 #include <glade/glade-xml.h>
 #include <gtk/gtkwidget.h>
+#include <gtk/gtk.h>
 #include <gtk/gtkliststore.h>
 #include "sj-extractor.h"
 
@@ -64,6 +65,7 @@ extern gboolean extracting;
  * The columns in the list view
  */
 typedef enum {
+  COLUMN_STATE,
   COLUMN_EXTRACT,
   COLUMN_NUMBER,
   COLUMN_TITLE,
@@ -73,6 +75,12 @@ typedef enum {
   COLUMN_TOTAL
 } ViewColumn;
 
+typedef enum {
+  STATE_IDLE,
+  STATE_PLAYING,
+  STATE_EXTRACTING
+} TrackState;
+
 /**
  * The GtkTreeModel which all of the tracks are stored in
  */
@@ -113,6 +121,11 @@ extern gboolean eject_finished;
  */
 extern gboolean autostart;
 
+/**
+ * Toggle, Title and Artist Renderers
+ */
+extern GtkCellRenderer *toggle_renderer, *title_renderer, *artist_renderer;
+
 /**
  * GConf key names
  */
@@ -133,4 +146,14 @@ extern gboolean autostart;
 #define GCONF_HTTP_PROXY GCONF_PROXY_ROOT "/host"
 #define GCONF_HTTP_PROXY_PORT GCONF_PROXY_ROOT "/port"
 
+/**
+ * Custom stock icons
+ */
+#define SJ_STOCK_PLAYING "sj-stock-playing"
+#define SJ_STOCK_RECORDING "sj-stock-recording"
+#define SJ_STOCK_EXTRACT "sj-stock-extract"
+
+/* TODO: need to add a SjWindow object or something */
+void sj_main_set_title (const char* detail);
+
 #endif /* SOUND_JUICER_H */
